@@ -1,8 +1,4 @@
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation; either version 3 of the License, or (at your option) any
-# later version.  See http://www.gnu.org/copyleft/lgpl.html for the full text
-# of the license.
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 __author__ = "Martin Pitt"
 __copyright__ = """
@@ -49,6 +45,8 @@ class TestAPI(dbusmock.DBusTestCase):
         self.p_mock = self.spawn_server(
             "org.freedesktop.Test", "/", "org.freedesktop.Test.Main", stdout=self.mock_log
         )
+        self.addCleanup(self.p_mock.wait)
+        self.addCleanup(self.p_mock.terminate)
 
         self.obj_test = self.dbus_con.get_object("org.freedesktop.Test", "/")
         self.dbus_test = dbus.Interface(self.obj_test, "org.freedesktop.Test.Main")
@@ -58,12 +56,6 @@ class TestAPI(dbusmock.DBusTestCase):
     def assertLog(self, regex):
         self.assertRegex(Path(self.mock_log.name).read_bytes(), regex)
 
-    def tearDown(self):
-        if self.p_mock.stdout:
-            self.p_mock.stdout.close()
-        self.p_mock.terminate()
-        self.p_mock.wait()
-
     def test_noarg_noret(self):
         """no arguments, no return value"""
 
